@@ -3,7 +3,7 @@ package Prty::ApplicationPaths;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Cwd ();
 use Hash::Util ();
@@ -64,7 +64,7 @@ Unix-Systems:
 Die Pfade müssen nicht im Root-Verzeichnis beginnen, ihnen kann
 auch Präfix-Pfad <prefix> vorangestellt sein, z.B. kann sich die
 Struktur im Home-Verzeichnis des Benutzers befinden
-(s. EXAMPLES).
+(s. L</EXAMPLES>).
 
 =head1 EXAMPLES
 
@@ -361,7 +361,7 @@ Trennzeichens erlaubt:
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
