@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Time::Local ();
 
@@ -248,7 +248,7 @@ und liefere diesen zurück.
 
 =head4 See Also
 
-timestampToEpoch()
+L</timestampToEpoch>()
 
 =cut
 
@@ -325,7 +325,7 @@ sub stringToKeyVal {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
