@@ -4,7 +4,7 @@ use base qw/Prty::Database::Row::Object Prty::ClassConfig/;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Prty::Hash;
 
@@ -64,7 +64,7 @@ Platzhalter, die bei einer Selektion durch die Selektionsskriterien
 ersetzt werden.
 
 Die Einsetzung von Selektionskriterien in das Template nimmt
-die Methode selectStmt() vor.
+die Methode L</selectStmt>() vor.
 
 =head4 Example
 
@@ -131,7 +131,7 @@ Select-Statement (String)
 
 Liefere ein Select-Statement der Klasse gemäß den Selektionskriterien
 C<@select>. Die Selektionskriterien werden in das Muster-Statement
-eingesetzt (siehe selectTemplate().
+eingesetzt (siehe L</selectTemplate>().
 
 =cut
 
@@ -269,7 +269,7 @@ sub cast {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
