@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Prty::Perl;
 
@@ -38,11 +38,11 @@ einzelnen Datenbank-Tabelle stammt.
 
 Die DML-Operationen (select, insert, update, delete) der Klasse
 operieren auf der Tabelle. Entsprechend definiert die Klasse einen
-Tabellennamen. Dieser wird von der Methode tableName() geliefert.
+Tabellennamen. Dieser wird von der Methode L</tableName>() geliefert.
 
 Über eine Tabelle wird vorausgesetzt, dass diese eine
 Primärschlüssel-Kolumne besitzt. Deren Name wird von der Methode
-primaryKey() geliefert.
+L</primaryKey>() geliefert.
 
 =head1 METHODS
 
@@ -436,7 +436,7 @@ sub delete {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
