@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Prty::Option;
 use Prty::String;
@@ -129,7 +129,7 @@ ausgegeben wird.
 
 =item -objectReturn => $bool (Default: 0)
 
-Liefere bei Aufruf von $exa->execute() nicht den Wert des
+Liefere bei Aufruf von $exa->L</execute>() nicht den Wert des
 Beispielcode, sondern ein Objekt, das den Beispielcode und
 den Wert enthält.
 
@@ -188,7 +188,7 @@ sub new {
 =head4 Description
 
 Setze Variable, so dass die folgende Kommando-Ausführung (Methode
-execute()) im Kontext der Klasse Prty::ExampleCode ausgeführt werden
+L</execute>()) im Kontext der Klasse Prty::ExampleCode ausgeführt werden
 kann. Die Methode liefert keinen Wert zurück.
 
 Anstelle mittels dieser Methode, können die Variablen auch beim Aufruf
@@ -246,7 +246,7 @@ Setzung ist nur im Falle von -objectReturn=>1 nötig
 
 =item -objectReturn => $bool (Default: 0)
 
-Liefere bei Aufruf von $exa->execute() nicht den Wert des
+Liefere bei Aufruf von $exa->L</execute>() nicht den Wert des
 Beispielcode, sondern ein Objekt, das den Beispielcode und
 den Wert enthält.
 
@@ -378,7 +378,7 @@ sub execute {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
