@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Prty::Shell;
 use Prty::Path;
@@ -69,7 +69,7 @@ Liefere den Künstler der Audio-Datei.
 
 =head4 See Also
 
-extractMetaData()
+L</extractMetaData>()
 
 =cut
 
@@ -99,7 +99,7 @@ Liefere den Titel der Audio-Datei.
 
 =head4 See Also
 
-extractMetaData()
+L</extractMetaData>()
 
 =cut
 
@@ -184,7 +184,7 @@ Liefere die Extension der Audio-Datei.
 
 =head4 See Also
 
-extractMetaData()
+L</extractMetaData>()
 
 =cut
 
@@ -305,7 +305,7 @@ sub extractMetaData {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
