@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Scalar::Util ();
 use Hash::Util ();
@@ -295,7 +295,7 @@ sub getRef {
 
 Liefere die Liste von Werten des Schlüssels $key. Im Skalarkontext
 liefere eine Referenz auf die Liste (der Aufruf hat dann die gleiche
-Wirkung wie der Aufruf von $h->get()). Der Wert von $key muss
+Wirkung wie der Aufruf von $h->L</get>()). Der Wert von $key muss
 eine Array-Referenz sein.
 
 =cut
@@ -319,7 +319,7 @@ sub getArray {
 
 =head4 Description
 
-Wie get(), nur dass im Falle eines unerlaubten Schlüssels
+Wie L</get>(), nur dass im Falle eines unerlaubten Schlüssels
 keine Exception geworfen, sondern C<undef> geliefert wird.
 
 =cut
@@ -407,7 +407,7 @@ sub set {
 
 =head4 Description
 
-Wie set(), nur dass im Falle eines unerlaubten Schlüssels keine
+Wie L</set>(), nur dass im Falle eines unerlaubten Schlüssels keine
 Exception generiert, sondern der Hash um das Schlüssel/Wert-Paar
 erweitert wird.
 
@@ -493,7 +493,7 @@ Der Rückgabewert der Subroutine wird an Schlüssel $key zugewiesen.
 
 =head4 Example
 
-Methode increment() mit apply() realisiert:
+Methode L</increment>() mit apply() realisiert:
 
     $val = $h->compute($key,sub {
         my ($h,$key) = @_;
@@ -548,7 +548,7 @@ Die Erzeugung einer Akzessor-Methode erfolgt (vom Aufrufer unbemerkt)
 beim ersten Aufruf. Danach wird die Methode unmittelbar aufgerufen.
 
 Der Zugriff über eine automatisch generierte Attributmethode ist ca. 30%
-schneller als über $h->get().
+schneller als über $h->L</get>().
 
 =cut
 
@@ -714,7 +714,7 @@ gleichen Schlüssel/Wert-Paaren. Es wird I<nicht> rekursiv kopiert,
 sondern eine "shallow copy" erzeugt.
 
 Sind Schlüssel/Wert-Paare @keyVal angegeben, werden
-diese nach dem Kopieren per set() auf dem neuen Hash gesetzt.
+diese nach dem Kopieren per L</set>() auf dem neuen Hash gesetzt.
 
 =cut
 
@@ -1240,7 +1240,7 @@ sub bucketsUsed {
 Ist Debug-Modus eingeschaltet, wird bei einem unerlaubten Zugriff
 via $h->get() oder $h->set() eine Exception mit Stacktrace
 geworfen. Per Default ist der Debug-Modus ausgeschaltet, um den
-Zugriffs-Overhead zu verringern. Siehe Abschnitt Benchmark.
+Zugriffs-Overhead zu verringern. Siehe Abschnitt L</Benchmark>.
 
 =cut
 
@@ -1323,7 +1323,7 @@ Zugriffsmethoden:
     C 8104988/s 478%  66%  53%   4%   --  -7%
     A 8745272/s 524%  79%  65%  12%   8%   --
 
-Den Hash via $h->get() zuzugreifen (F) ist ca. 85% langsamer
+Den Hash via $h->L</get>() zuzugreifen (F) ist ca. 85% langsamer
 als der einfachste Hash-Lookup (A). Wird auf den Methodenaufruf
 verzichtet und per $h->{$key} zugegriffen (E), ist der Zugriff nur
 11% langsamer. Es ist also ratsam, intern per $h->{$key}
@@ -1332,9 +1332,9 @@ CPU-Sekunde ausgeführt werden. Bei nicht-zugriffsintensiven
 Anwendungen ist das sicherlich schnell genug. Bei eingeschaltetem
 Debug-Modus halbiert sich diese Anzahl wegen des eval{} in etwa,
 daher ist der Debug-Modus per Default ausgeschaltet. Siehe Methode
-$h->debugMode(). Die Anzahl der Aufrufe von $h->get() und $h->set()
-wird intern gezählt und kann per $class->getCount() und
-$class->setCount() abgefragt werden.
+$h->L</debugMode>(). Die Anzahl der Aufrufe von $h->get() und $h->set()
+wird intern gezählt und kann per $class->L</getCount>() und
+$class->L</setCount>() abgefragt werden.
 
 Das Benchmark-Programm (bench-hash):
 
@@ -1375,7 +1375,7 @@ Das Benchmark-Programm (bench-hash):
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
