@@ -4,7 +4,7 @@ use base qw/Prty::Html::Base/;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 # -----------------------------------------------------------------------------
 
@@ -35,7 +35,7 @@ Unordered List (<ul>)
 
 =back
 
-erzeugen. Siehe Abschnitt EXAMPLES.
+erzeugen. Siehe Abschnitt L</EXAMPLES>.
 
 =head1 ATTRIBUTES
 
@@ -188,7 +188,7 @@ sub html {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
