@@ -4,7 +4,7 @@ use base qw/Prty::File::Image/;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 # -----------------------------------------------------------------------------
 
@@ -69,7 +69,7 @@ sub new {
 =head2 Objektmethoden
 
 Alle weiteren Methoden befinden sich bei der Basisklasse (s. Abschnitt
-BASE CLASS).
+L</"BASE CLASS">).
 
 =head3 number() - Nummer des Bildes
 
@@ -115,7 +115,7 @@ sub cacheId {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
