@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Prty::Hash;
 
@@ -24,8 +24,8 @@ L<Prty::Hash>
 
 Die Klasse erzeugt den HTML-Code einer jQuery UI Accordion Reiterleiste.
 Dem Konstruktor wird die Reiterkonfiguration mit dem Attribut
-C<tabs> übergeben. Die Methode html() generiert den HTML-Code.
-Siehe Abschnitt EXAMPLE.
+C<tabs> übergeben. Die Methode L</html>() generiert den HTML-Code.
+Siehe Abschnitt L</EXAMPLE>.
 
 =head1 ATTRIBUTES
 
@@ -175,7 +175,7 @@ sub html {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 SEE ALSO
 
