@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Prty::Html::Table::List;
 use Prty::Unindent;
@@ -27,12 +27,12 @@ L<Prty::Hash>
 =begin html
 
 <p class="sdoc-fig-p">
-  <img class="sdoc-fig-img" src="https://raw.github.com/s31tz/Prty/master/img/prty_jquery_datatable_example01.png" width="499" height="149" alt="" />
+  <img class="sdoc-fig-img" src="https://raw.github.com/s31tz/Prty/master/img/prty_jquery_datatable_example01.png" width="757" height="170" alt="" />
 </p>
 
 =end html
 
-Quelltext siehe L</"EXAMPLE">.
+Quelltext siehe Abschnitt L</"Beispiel Synopsis">.
 
 =head1 DESCRIPTION
 
@@ -46,6 +46,13 @@ DataTable-Widget.
 
 =over 4
 
+=item arguments => $json (Default: undef)
+
+JSON-Code der das DataTable-Objekt in JavaScript instantiiert. Die
+äußeren geschweiften Klammern werden hierbei weggelassen. Die
+Kolumnendefinitionen (DataTables-Attribut columns:) wird intern
+generiert und zu diesem Code hinzugefügt.
+
 =item class => $class (Default: undef)
 
 CSS-Klasse der DataTable (des Table-Elements).
@@ -75,13 +82,6 @@ DOM-Id der DataTable (des Table-Elements).
 Füge die Instantiierung des DataTable-Objektes (JavaScript) zum
 HTML-Code der Methode html() hinzu.
 
-=item json => $json (Default: undef)
-
-JSON-Code der das DataTable-Objekt in JavaScript instantiiert. Die
-äußeren geschweiften Klammern werden hierbei weggelassen. Die
-Kolumnendefinitionen (DataTables-Attribut columns:) wird intern
-generiert und zu diesem Code hinzugefügt.
-
 =item rowCallback => $sub (Default: s.u.)
 
 Referenz auf eine Subroutine, die für jedes Row-Objekt die
@@ -107,9 +107,142 @@ Liste der Row-Objekte. Für jedes Element wird die Callback-Methode
 
 =back
 
-=head1 EXAMPLE
+=head1 EXAMPLES
 
-Programm:
+=head2 Beispiel Synopsis
+
+Default-Aussehen einer DataTable:
+
+=begin html
+
+<p class="sdoc-fig-p">
+  <img class="sdoc-fig-img" src="https://raw.github.com/s31tz/Prty/master/img/prty_jquery_datatable_example01.png" width="757" height="170" alt="" />
+</p>
+
+=end html
+
+Das Programm
+
+    my $tab = Prty::Database::Row::Object->makeTable(
+        [qw/per_id per_vorname per_nachname per_geburtsdatum/],
+        qw/1 Rudi Ratlos 1971-04-23/,
+        qw/2 Erika Mustermann 1955-03-16/,
+        qw/3 Harry Hirsch 1948-07-22/,
+        qw/4 Susi Sorglos 1992-10-23/,
+    );
+    
+    my $h = Prty::Html::Tag->new('html-5');
+    
+    my $html = Prty::JQuery::DataTable->html($h,
+        id=>'personTable',
+        class=>'compact stripe hover cell-border',
+        columns=>[
+            {
+                name=>'per_id',
+                title=>'Id',
+                align=>'right',
+            },{
+                name=>'per_vorname',
+                title=>'Vorname',
+            },{
+                name=>'per_nachname',
+                title=>'Nachname',
+            },{
+                name=>'per_geburtsdatum',
+                title=>'Geburtstag',
+                align=>'center',
+            },
+        ],
+        rows=>scalar $tab->rows,
+        instantiate=>1,
+    );
+
+erzeugt den HTML-Code (lange Zeilen umbrochen)
+
+    <table id="personTable" class="compact stripe hover cell-border"
+      cellspacing="0">
+    <thead>
+      <tr>
+        <th>Id</th>
+        <th>Vorname</th>
+        <th>Nachname</th>
+        <th>Geburtstag</th>
+      </tr>
+    </thead>
+    <tbody>
+      <tr>
+        <td>1</td>
+        <td>Rudi</td>
+        <td>Ratlos</td>
+        <td>1971-04-23</td>
+      </tr>
+      <tr>
+        <td>2</td>
+        <td>Erika</td>
+        <td>Mustermann</td>
+        <td>1955-03-16</td>
+      </tr>
+      <tr>
+        <td>3</td>
+        <td>Harry</td>
+        <td>Hirsch</td>
+        <td>1948-07-22</td>
+      </tr>
+      <tr>
+        <td>4</td>
+        <td>Susi</td>
+        <td>Sorglos</td>
+        <td>1992-10-23</td>
+      </tr>
+    </tbody>
+    </table>
+    <script type="text/javascript">
+      jQuery('#personTable').DataTable({
+        columns: [
+          {
+            className: 'dt-right',
+          },{
+            className: 'dt-left',
+          },{
+            className: 'dt-left',
+          },{
+            className: 'dt-center',
+          },
+        ],
+      });
+    </script>
+
+=head2 Mit Instantiierungs-Argumenten (ganze HTML-Seite)
+
+Beispiel für die Angabe von Instantiierungs-Argumenten. Dies
+kann bei Aufruf der Methode L</instantiate>()
+
+    $dt->instantiate(q~
+        fixedHeader: true,
+        stateSave: true,
+        dom: 't',
+    ~),
+
+oder durch Zuweisung an das Attribut instantiate erfolgen
+
+    instantiate=>q~
+        fixedHeader: true,
+        stateSave: true,
+        dom: 't',
+    ~
+
+Die Angabe C<dom: 't'> bewirkt hier, dass das DataTables-Plugin
+keine Bedienelemente erzeugt:
+
+=begin html
+
+<p class="sdoc-fig-p">
+  <img class="sdoc-fig-img" src="https://raw.github.com/s31tz/Prty/master/img/prty_jquery_datatable_example02.png" width="757" height="117" alt="" />
+</p>
+
+=end html
+
+Das Programm
 
     my $tab = Prty::Database::Row::Object->makeTable(
         [qw/per_id per_vorname per_nachname per_geburtsdatum/],
@@ -142,17 +275,6 @@ Programm:
             },
         ],
         rows=>scalar $tab->rows,
-        json=>q~
-            paging: false,
-            info: false,
-            fixedHeader: true,
-            stateSave: true,
-            dom: 'ft',
-            language: {
-                search: 'Suche:',
-                zeroRecords: 'Keine Daten',
-            },
-        ~
     );
     
     my $html = Prty::Html::Page->html($h,
@@ -169,11 +291,15 @@ Programm:
         javaScript=>[
             'https://code.jquery.com/jquery-1.10.2.js',
             Prty::JQuery::DataTable->pluginUrl,
-            $dt->instantiate,
+            $dt->instantiate(q~
+                fixedHeader: true,
+                stateSave: true,
+                dom: 't',
+            ~),
         ],
     );
 
-Generierter HTML-Code:
+erzeugt den HTML-Code (lange Zeilen umbrochen)
 
     <!DOCTYPE html>
     
@@ -236,15 +362,9 @@ Generierter HTML-Code:
       </script>
       <script type="text/javascript">
         jQuery('#personTable').DataTable({
-          paging: false,
-          info: false,
           fixedHeader: true,
           stateSave: true,
-          dom: 'ft',
-          language: {
-            search: 'Suche:',
-            zeroRecords: 'Keine Daten',
-          },
+          dom: 't',
           columns: [
             {
               className: 'dt-right',
@@ -345,11 +465,11 @@ sub new {
     # @_: @attVal
 
     my $self = $class->SUPER::new(
+        arguments=>undef,
         class=>undef,
         columns=>[],
         id=>undef,
         instantiate=>0,
-        json=>undef,
         rowCallback=>undef,
         rows=>[],
     );
@@ -385,8 +505,8 @@ sub html {
 
     my $self = ref $this? $this: $this->new(@_);
 
-    my ($class,$id,$instantiate,$json,$rowCallback,$rowA) =
-        $self->get(qw/class id instantiate json rowCallback rows/);
+    my ($arguments,$class,$id,$instantiate,$rowCallback,$rowA) =
+        $self->get(qw/arguments class id instantiate rowCallback rows/);
 
     # Liste der Kolumnendefinitionen als Hash-Objekte
     my @columns = $self->getColumns;
@@ -444,6 +564,7 @@ sub html {
 =head4 Synopsis
 
     $javaScript = $e->instantiate;
+    $javaScript = $e->instantiate($json);
 
 =head4 Description
 
@@ -462,9 +583,12 @@ instantiiert. Aufbau:
 # -----------------------------------------------------------------------------
 
 sub instantiate {
-    my $self = shift;
+    my ($self,$json) = @_;
 
-    my ($id,$json) = $self->get(qw/id json/);
+    my ($id,$arguments) = $self->get(qw/id arguments/);
+
+    $arguments = Prty::Unindent->string($arguments);
+    $arguments .= Prty::Unindent->string($json);
 
     my $columns;
     for my $col ($self->getColumns) {
@@ -494,11 +618,10 @@ sub instantiate {
     }
     $columns =~ s/^/    /mg;
 
-    $json = Prty::Unindent->string($json).
-        "columns: [\n$columns\n],\n";
-    $json =~ s/^/    /mg;
+    $arguments .= "columns: [\n$columns\n],\n";
+    $arguments =~ s/^/    /mg;
 
-    return sprintf qq|jQuery('#%s').DataTable({\n%s\n});|,$id,$json;
+    return sprintf qq|jQuery('#%s').DataTable({\n%s\n});|,$id,$arguments;
 }
 
 # -----------------------------------------------------------------------------
@@ -550,7 +673,7 @@ sub getColumns {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
