@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Prty::Hash;
 use Prty::Html::List;
@@ -25,8 +25,8 @@ L<Prty::Hash>
 
 Die Klasse erzeugt den HTML-Code einer jQuery UI Reiterleiste.
 Dem Konstruktor wird die Reiterkonfiguration mit dem Attribut
-C<tabs> übergeben. Die Methode html() generiert den HTML-Code.
-Siehe Abschnitt EXAMPLE.
+C<tabs> übergeben. Die Methode L</html>() generiert den HTML-Code.
+Siehe Abschnitt L</EXAMPLE>.
 
 =head1 ATTRIBUTES
 
@@ -183,7 +183,7 @@ sub html {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 SEE ALSO
 
