@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Prty::Object;
 use Prty::Array;
@@ -184,7 +184,7 @@ Variable $@ gibt den Grund an.
 
 =head4 See Also
 
-loadClass()
+L</loadClass>()
 
 =cut
 
@@ -516,7 +516,7 @@ sub classExists {
 
 =head4 Description
 
-Lade Klasse $class. Im Unterschied zu Methode use() wird die
+Lade Klasse $class. Im Unterschied zu Methode L</use>() wird die
 Moduldatei nur zu laden versucht, wenn es den Namensraum (Package)
 der Klasse noch nicht gibt.
 
@@ -1641,11 +1641,11 @@ Die Liste entspricht dem Ergebnis des Aufrufs
 
 =item *
 
-additionalIncPaths()
+L</additionalIncPaths>()
 
 =item *
 
-incPaths()
+L</incPaths>()
 
 =back
 
@@ -1686,11 +1686,11 @@ Suchpfade des Perl_interpreters hinausgehen.
 
 =item *
 
-basicIncPaths()
+L</basicIncPaths>()
 
 =item *
 
-incPaths()
+L</incPaths>()
 
 =back
 
@@ -1731,11 +1731,11 @@ Referenz auf das Array.
 
 =item *
 
-basicIncPaths()
+L</basicIncPaths>()
 
 =item *
 
-additionalIncPaths()
+L</additionalIncPaths>()
 
 =back
 
@@ -1871,7 +1871,7 @@ sub removePod {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
