@@ -4,7 +4,7 @@ use base qw/Prty::Process Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Prty::Perl;
 use Encode ();
@@ -90,7 +90,7 @@ Optionen und Argumente:
 
 =head4 Options
 
-Siehe Methode new()
+Siehe Methode L</new>()
 
 =cut
 
@@ -153,7 +153,7 @@ sub run {
 Terminiere das Programm mit Exitcode $exitCode. Ist kein Exitcode
 angegeben, terminiere mit dem Exitcode der auf dem Programmobjekt
 gesetzt ist. Die Methode kehrt nicht zurück. Nach ihrem Aufruf wird
-die Methode finish() ausgeführt.
+die Methode L</finish>() ausgeführt.
 
 =cut
 
@@ -254,7 +254,7 @@ Das Default-Verhalten ist, dass der Exception-Text auf STDERR
 ausgegeben und der Exitcode auf 99 gesetzt wird.
 
 Das Programm terminiert nicht sofort, sondern die Methode
-finish() wird noch ausgeführt.
+L</finish>() wird noch ausgeführt.
 
 =cut
 
@@ -756,7 +756,7 @@ sub new {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
