@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 # -----------------------------------------------------------------------------
 
@@ -47,7 +47,7 @@ Einrücktiefe bei der Codegenerierung
 =head4 Description
 
 Instantiiere einen Sdoc-Generator mit den Eigenschaften @keyVal
-(s. Abschnitt Attributes) und liefere eine Referenz auf dieses
+(s. Abschnitt L</Attributes>) und liefere eine Referenz auf dieses
 Objekt zurück.
 
 =head4 Example
@@ -322,7 +322,7 @@ sub eof {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
