@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Prty::Array;
 use Prty::Converter;
@@ -648,7 +648,8 @@ sub linkSegment {
         );
     }
     elsif ($format eq 'pod') {
-        return qq|L</"$anchor">|;
+        # Wenn Whitespace im Anker, in "..." einfassen
+        return $anchor =~ /\s/? qq|L</"$anchor">|: "L</$anchor>";
     }
 
     return $anchor;
@@ -844,7 +845,7 @@ sub tableOfContents {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
