@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 # -----------------------------------------------------------------------------
 
@@ -472,7 +472,7 @@ Wert (Skalar-Kontext) oder Wertliste (Array-Kontext)
 Liefere den Wert zu Schlüssel $key bzw. die liste der Werte zu den
 Schlüsseln @keys. Beginnt der $key mit einem Großbuchstaben, ist
 es ein fataler Fehler, wenn zu dem Schlüssel mehrere Werte existieren.
-Solche Schlüssel müssen mit $obj->getArray() abgefragt werden.
+Solche Schlüssel müssen mit $obj->L</getArray>() abgefragt werden.
 
 =cut
 
@@ -628,7 +628,7 @@ Wert (Skalar)
 
 =head4 Description
 
-Wie $sec->get(), nur dass ein Wert existieren muss, sonst
+Wie $sec->L</get>(), nur dass ein Wert existieren muss, sonst
 wird eine Exception geworfen.
 
 =cut
@@ -680,7 +680,7 @@ sub getRef {
 
 =head4 Description
 
-Wie get(), nur dass im Falle eines unerlaubten Schlüssels
+Wie L</get>(), nur dass im Falle eines unerlaubten Schlüssels
 keine Exception geworfen, sondern C<undef> geliefert wird.
 
 =cut
@@ -749,7 +749,7 @@ sub memoize {
 
 =head4 Description
 
-Die Methode ist identisch zu $sec->memoize(), nur dass eine
+Die Methode ist identisch zu $sec->L</memoize>(), nur dass eine
 Referenz ermittelt und automatisch zu einer schwachen Referenz
 gemacht wird.
 
@@ -1110,7 +1110,7 @@ sub AUTOLOAD {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
