@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Prty::FileHandle;
 use Prty::Hash;
@@ -182,7 +182,7 @@ die Liste (Skalar-Kontext).
 
 Parse die Eingabe und liefere die Liste der Abschnittsobjekte zurück.
 Die Eingabe besteht aus einer Folge von 0 bis n
-Syntax. Die Methode kann wiederholt mit
+L</Syntax>. Die Methode kann wiederholt mit
 verschiedenen Eingaben aufgerufen werden.
 
 =cut
@@ -501,7 +501,7 @@ gerufen.
 Die Methode instantiiert per Default ein Objekt der Klasse
 C<< Prty::Section::Object >> und liefert eine Referenz auf dieses Objekt
 zurück. Das Objekt wird zur Liste der Abschnittsobjekte hinzugefügt.
-Die Liste der Abschnittsobjekte wird von der Methode parse()
+Die Liste der Abschnittsobjekte wird von der Methode L</parse>()
 zurückgeliefert. In abgeleiteten Klassen kann die Methode überschrieben
 und ein anderes Verhalten implementiert werden.
 
@@ -656,7 +656,7 @@ zählt nicht zum I<CONTENT> hinzu.
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
