@@ -3,7 +3,7 @@ package Prty::Stacktrace;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 # -----------------------------------------------------------------------------
 
@@ -82,7 +82,7 @@ bzw.
     $ less +17 ./test.pl
 
 Der unterste Eintrag im Stacktrace ist der Aufruf des
-Konstruktors new() oder der Methode asString(), wenn sie
+Konstruktors L</new>() oder der Methode L</asString>(), wenn sie
 als Klassenmethode gerufen wird. Sollen Stacktrace-Frames am
 Ende weggelassen werden, kann dies durch Angabe des Parameters
 $i erreicht werden.
@@ -151,7 +151,7 @@ sub new {
 
 =item $i (Default: 0)
 
-Siehe new().
+Siehe L</new>().
 
 =back
 
@@ -189,7 +189,7 @@ sub asString {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
