@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 use Prty::Path;
 use Scalar::Util ();
@@ -159,7 +159,7 @@ Ersetze alle Platzhalter durch ihre Werte. Platzhalter und
 Werte werden als Paare @keyVal übergeben.
 
 Der Wert kann ein String, eine Arrayrefernz, eine Codereferenz oder
-ein Template-Objekt sein. Siehe Methode value().
+ein Template-Objekt sein. Siehe Methode L</value>().
 
 Es wird für jeden Platzhalter mit einem Wert ungleich C<undef> geprüft,
 ob dieser im Template vorkommt. Wenn nicht, wird eine Exception geworfen.
@@ -202,7 +202,7 @@ Subroutine liefert Platzhalter-Wert:
 Die Subroutine, die den Wert des Platzhalters __ORDERLINES__ berechnet,
 liefert keinen String, sondern eine Referenz auf ein Array von
 Template-Objekten. Wie jeder Platzhalterwert wird dieser von der
-Methode $tpl->value() in einen String (oder C<undef>) umgesetzt.
+Methode $tpl->L</value>() in einen String (oder C<undef>) umgesetzt.
 
 =cut
 
@@ -380,7 +380,7 @@ sub key {
 
 =head3 Description
 
-Die Methode liefert die Zeichenkette $str zum (bei replace()
+Die Methode liefert die Zeichenkette $str zum (bei L</replace>()
 angegebenen) Platzhalter-Wert $arg.
 
 =over 4
@@ -401,7 +401,7 @@ Returnwerts.
 
 =item Template-Objekt:
 
-Rufe Methode asString() des Objekts auf und liefere
+Rufe Methode L</asString>() des Objekts auf und liefere
 das Resultat zurück.
 
 =back
@@ -737,7 +737,7 @@ sub asStringNL {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
