@@ -3,7 +3,7 @@ package Prty::Unindent;
 use strict;
 use warnings;
 
-our $VERSION = 1.094;
+our $VERSION = 1.095;
 
 # -----------------------------------------------------------------------------
 
@@ -187,7 +187,7 @@ sub hereDoc {
 
 =head4 Description
 
-Wie Methode hereDoc(), wobei über die Einrückung hinaus
+Wie Methode L</hereDoc>(), wobei über die Einrückung hinaus
 
 =over 2
 
@@ -273,7 +273,7 @@ sub string {
 
 =head4 Description
 
-Wie die Methoden hereDoc() und string(), wobei über die
+Wie die Methoden L</hereDoc>() und L</string>(), wobei über die
 Einrückung hinaus
 
 =over 2
@@ -373,7 +373,7 @@ sub trim {
 
 =head1 VERSION
 
-1.094
+1.095
 
 =head1 AUTHOR
 
